@@ -118,12 +118,10 @@ MainWindow::MainWindow(QWidget *parent) :
     headerView->setResizeMode(2, QHeaderView::ResizeToContents);
     headerView->setResizeMode(3, QHeaderView::ResizeToContents);
     headerView->setResizeMode(4, QHeaderView::ResizeToContents);
-    connect(tableView, SIGNAL(entered(QModelIndex)),
-            this, SLOT(taskSelected(QModelIndex)));
-    connect(tableView, SIGNAL(clicked(QModelIndex)),
-            this, SLOT(taskSelected(QModelIndex)));
-    connect(tableView, SIGNAL(pressed(QModelIndex)),
-            this, SLOT(taskSelected(QModelIndex)));
+
+    QItemSelectionModel *selectionModel = tableView->selectionModel();
+    connect(selectionModel, SIGNAL(selectionChanged(QItemSelection, QItemSelection)),
+            this, SLOT(taskSelected(QItemSelection, QItemSelection)));
 
     taskDialog = new TaskDialog(this);
     connect(ui->addButton, SIGNAL(clicked()), taskDialog, SLOT(show()));
@@ -210,16 +208,25 @@ void MainWindow::externalInterruption()
 }
 
 
-void MainWindow::taskSelected(const QModelIndex &index)
+void MainWindow::taskSelected(const QItemSelection &selected,
+    const QItemSelection &/*deselected*/)
 {
-    qDebug("MainWindow::taskSelected");
+    QModelIndexList indexes = selected.indexes();
 
-    selectedIndex = index;
+    if (indexes.count()) {
+        selectedIndex = selected.indexes().at(0);
 
-    if (!pomodoroModel->isTaskCompleted(index))
-        setUiState(IdleTaskSelected);
-    else
-        setUiState(IdleCompletedTaskSelected);
+        qDebug("MainWindow::taskSelected selectedIndex.row()=%i",
+            selectedIndex.row());
+
+        if (!pomodoroModel->isTaskCompleted(selectedIndex))
+            setUiState(IdleTaskSelected);
+        else
+            setUiState(IdleCompletedTaskSelected);
+    } else {
+        qDebug("MainWindow::taskSelected (no selection)");
+        setUiState(IdleNoSelection);
+    }
 }
 
 void MainWindow::pomodoroStarted(int /*lengthInSeconds*/)
@@ -271,13 +278,13 @@ void MainWindow::showGuide()
 
     QString title = tr("What is a pomodoro?");
     QString text =
-            tr("\"Pomodoro\" is a 25 minute session of focused work. Between pomodoros "
+            tr("Pomodoro is a 25 minute session of focused work. Between pomodoros "
                "take a 5 minute break and every 4 pomodoros a longer break. "
                "Internal interruption means that you have been interrupted by "
                "yourself, you did something not in the scope of the task. "
                "External interruption means that someone else interrupted you."
                "\n\n"
-               "For details on The Pomodoro Technique see <http://www.pomodorotechnique.com/>.");
+               "See http://www.pomodorotechnique.com/ for details on The Pomodoro Technique.");
 
     QMessageBox::information(this, title, text);
 
@@ -288,7 +295,8 @@ void MainWindow::showGuide()
               "on Int./Ext. button depending on the distraction type."
               "\n\n"
               "Mark the task completed when it's done. Completed tasks will "
-              "be hidden from the task list the next day.");
+              "be hidden from the task list the next day.\n\n"
+              "You can access this guide again at any time from the application menu.");
 
     QMessageBox::information(this, title, text);
 }
